tlslite

Package tlslite |
[show private | hide private]
[frames | no frames]

## Package tlslite

TLS Lite is a free python library that implements SSL v3, TLS v1, and TLS v1.1. TLS Lite supports non-traditional authentication methods such as SRP, shared keys, and cryptoIDs, in addition to X.509 certificates. TLS Lite is pure python, however it can access OpenSSL, cryptlib, pycrypto, and GMPY for faster crypto operations. TLS Lite integrates with httplib, xmlrpclib, poplib, imaplib, smtplib, SocketServer, asyncore, and Twisted.

To use, do:

       from tlslite.api import *

Then use the `tlslite.TLSConnection.TLSConnection` class with a socket, or use one of the integration classes in `tlslite.integration`.

Version: 0.3.8

Submodules
`api`: Import this module for easy access to TLS Lite objects. `BaseDB`: Base class for SharedKeyDB and VerifierDB. `Checker`: Class for post-handshake certificate checking. `constants`: Constants used in various places. `errors`: Exception classes. `FileObject`: Class returned by TLSConnection.makefile(). `HandshakeSettings`: Class for setting handshake parameters. `integration`: Classes for integrating TLS Lite with other packages. `AsyncStateMachine`: A state machine for using TLS Lite with asynchronous I/O. `HTTPTLSConnection`: TLS Lite + httplib. `IMAP4_TLS`: TLS Lite + imaplib. `POP3_TLS`: TLS Lite + poplib. `SMTP_TLS`: TLS Lite + smtplib. `TLSAsyncDispatcherMixIn`: TLS Lite + asyncore. `TLSSocketServerMixIn`: TLS Lite + SocketServer. `TLSTwistedProtocolWrapper`: TLS Lite + Twisted. `XMLRPCTransport`: TLS Lite + xmlrpclib. `mathtls`: Miscellaneous helper functions. `messages`: Classes representing TLS messages. `Session`: Class representing a TLS session. `SessionCache`: Class for caching TLS sessions. `SharedKeyDB`: Class for storing shared keys. `TLSConnection`: MAIN CLASS FOR TLS LITE (START HERE!). `TLSRecordLayer`: Helper class for TLSConnection. `utils`: Toolkit for crypto and other stuff. `AES`: Abstract class for AES. `ASN1Parser`: Class for parsing ASN.1 `cipherfactory`: Factory functions for symmetric cryptography. `codec`: Classes for reading/writing binary data (such as TLS records). `compat`: Miscellaneous functions to mask Python version differences. `Cryptlib_AES`: Cryptlib AES implementation. `Cryptlib_RC4`: Cryptlib RC4 implementation. `Cryptlib_TripleDES`: Cryptlib 3DES implementation. `dateFuncs` `hmac`: HMAC (Keyed-Hashing for Message Authentication) Python module. `keyfactory`: Factory functions for asymmetric cryptography. `OpenSSL_AES`: OpenSSL/M2Crypto AES implementation. `OpenSSL_RC4`: OpenSSL/M2Crypto RC4 implementation. `OpenSSL_RSAKey`: OpenSSL/M2Crypto RSA implementation. `OpenSSL_TripleDES`: OpenSSL/M2Crypto 3DES implementation. `PyCrypto_AES`: PyCrypto AES implementation. `PyCrypto_RC4`: PyCrypto RC4 implementation. `PyCrypto_RSAKey`: PyCrypto RSA implementation. `PyCrypto_TripleDES`: PyCrypto 3DES implementation. `Python_AES`: Pure-Python AES implementation. `Python_RC4`: Pure-Python RC4 implementation. `Python_RSAKey`: Pure-Python RSA implementation. `RC4`: Abstract class for RC4. `rijndael`: A pure python (slow) implementation of rijndael with a decent interface `RSAKey`: Abstract class for RSA. `TripleDES`: Abstract class for 3DES. `xmltools`: Helper functions for XML. `VerifierDB`: Class for storing SRP password verifiers. `X509`: Class representing an X.509 certificate. `X509CertChain`: Class representing an X.509 certificate chain.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net